@@ -10,30 +10,32 @@ from . import exc
 
 class Cipher(ABC):
     """Base cipher for all other ciphers."""
+
     @abstractmethod
     def update(self, data):
-        """Takes bytes-like object and returns
-        encrypted/decrypted bytes object.
+        """Takes bytes-like object and returns encrypted/decrypted
+        bytes object.
 
         Args:
-            data: The bytes-like object to pass to the cipher.
+            data (bytes, bytesarray):
+                The bytes-like object to pass to the cipher.
 
         Returns:
-            bytes-like encrypted data.
+            bytes: bytes-like encrypted data.
         """
 
     @abstractmethod
     def update_into(self, data, out):
-        """Works almost like `update` method, except
-        for it fills a preallocated buffer with data
-        with no intermideate copying of data.
+        """Works almost like :py:attr:`~Cipher.update` method, except for
+        it fills a preallocated buffer with data with no intermideate
+        copying of data.
 
         Args:
-            data:
+            data (bytes, bytearray, memoryview):
                 The bytes-like object to pass to the cipher.
-            out:
-                The buffer interface where the encrypted/decrypted
-                data must be written into.
+            out (bytearray, memoryview):
+                The buffer interface where the encrypted/decrypted data
+                must be written into.
 
         Returns:
             None
@@ -42,19 +44,20 @@ class Cipher(ABC):
     @abstractmethod
     def authenticate(self, data):
         """Authenticates additional data.
-        Data must be a bytes, bytearray or memoryview object.
-        You can call it to pass additional data that must be
-        authenticated, but would be transmitted in the clear.
+        Data must be a bytes, bytearray or memoryview object. You can call
+        it to pass additional data that must be authenticated, but would be
+        transmitted in the clear.
 
         Args:
-            data: The bytes-like object that must be authenticated.
+            data (bytes, bytearray, memoryview):
+                The bytes-like object that must be authenticated.
 
         Returns:
             None
 
         Raises:
-            TypeError is raised if this method is called after calling
-            `update`.
+            TypeError:
+                if this method is called after calling :py:attr:`~Cipher.update`.
         """
 
     @abstractmethod
@@ -62,7 +65,7 @@ class Cipher(ABC):
         """Finalizes and closes the cipher.
 
         Args:
-            tag:
+            tag (bytes, bytearray):
                 The associated tag that authenticates the decryption.
                 `tag` is required for decryption only. If the mode is
                 not AEAD, tag is not required for verification.
@@ -78,16 +81,13 @@ class Cipher(ABC):
     @abstractmethod
     def calculate_tag(self):
         """Calculates and returns the associated `tag`.
-        Args:
-            None
 
         Returns:
-            `None` if decrypting.
-            bytes-like tag if encrypting.
+            If encrypting, it returns `None`, otherwise a `bytes` object.
 
         Raises:
-            NotImplementedError if the mode is non-AEAD or cipher doesn't
-            support AEAD.
+            NotImplementedError:
+                if the mode is non-AEAD or cipher doesn't support AEAD.
         """
 
 
@@ -107,7 +107,8 @@ class BaseHash(ABC):
         """Update the hash function
 
         Args:
-            data: The bytes-like object to pass to the hash algorithm.
+            data (bytes, bytearray):
+                The bytes-like object to pass to the hash algorithm.
 
         Returns:
             None
@@ -118,51 +119,47 @@ class BaseHash(ABC):
         """Return a copy of the hash function.
         This cannot be called after digest has been called.
 
-        Args:
-            None
-
         Returns:
-            Hash object.
+            :any:`BaseHash`: Hash object.
         """
 
     @abstractmethod
     def digest(self):
         """Finalize and return the hash as bytes object.
 
-        Args:
-            None
-
         Returns:
-            bytes object representing the digest of the message.
+            bytes: bytes object representing the digest of the message.
         """
 
     @abstractmethod
-    def new(self, data=b'', *, digest_size=None):
+    def new(self, data=b"", *, digest_size=None):
         """Return a new hash object.
 
         Args:
-            data: The initial data to be passed to the hash object.
+            data (bytes, bytearray):
+                The initial data to be passed to the hash object.
 
-        Kwargs:
-            digest_size:
+        Keyword Arguments:
+            digest_size (int):
                 The digest size of the hash algorithm.
                 If digest_size is None, it is equal to the current
                 hash object's digest size.
-                Valid only for BLAKE and SHAKE.
+                Valid only for `BLAKE` and `SHAKE`.
 
         Returns:
-            Hash object.
+            :any:`BaseHash`: Hash object.
 
-        Raises:
-            See documentation for Hash.
+        Note:
+            See documentation for :func:`pyflocker.ciphers.interfaces.Hash.new`.
         """
 
-    def __repr__(self):
+    def __repr__(self):  # pragma: no cover
         return f"<Hash '{self.name}' at {hex(id(self))}>"
 
 
 class BaseAsymmetricKey(ABC):
     """Represents the base key interface."""
+
     @abstractmethod
     def serialize(self):
         """Serialize the key into a storable format."""
@@ -175,16 +172,14 @@ class BaseAsymmetricKey(ABC):
 
 class BasePrivateKey(BaseAsymmetricKey):
     """Represents the base interface for private key."""
-    @abstractmethod
-    def signer(self):
-        """Instantiate and return a signer object."""
+
+    pass
 
 
 class BasePublicKey(BaseAsymmetricKey):
     """Represents the base interface for public key."""
-    @abstractmethod
-    def verifier(self):
-        """Instantiate and return a verifier object."""
+
+    pass
 
 
 # ===========================================================
@@ -195,20 +190,20 @@ def finalizer(f=None, *, allow=False):
     """Finalizes the cipher.
 
     Args:
-        f: The method to wrap.
-        allow:
+        f (function): The method to wrap.
+        allow (bool):
             setting `allow` to True means that this function can
             be called multiple times even after finalization.
 
     Returns:
-        The wrapped function.
+        function: The wrapped function.
     """
     if f is None:
         return partial(finalizer, allow=allow)
 
     @wraps(f)
     def wrapper(self, *args, **kwargs):
-        if hasattr(self, '_done_') and not allow:
+        if hasattr(self, "_done_") and not allow:
             raise exc.AlreadyFinalized("cipher has already been finalized")
 
         try:
@@ -224,14 +219,17 @@ def before_finalized(f):
     """Methods decorated with this decorator can only be called
     before the cipher has been finalized.
 
-    see: `finalizer`
+    See also:
+        :func:`~pyflocker.ciphers.base.finalizer`
     """
+
     @wraps(f)
     def wrapper(self, *args, **kwargs):
-        if not hasattr(self, '_done_'):
+        if not hasattr(self, "_done_"):
             return f(self, *args, **kwargs)
         raise exc.AlreadyFinalized(
-            "this method can only be called before finalizing")
+            "this method can only be called before finalizing"
+        )
 
     return wrapper
 
@@ -240,14 +238,17 @@ def after_finalized(f):
     """Methods decorated with this decorator can only be called
     after the cipher has been finalized.
 
-    see: `finalizer`
+    See also:
+        :func:`~pyflocker.ciphers.base.finalizer`
     """
+
     @wraps(f)
     def wrapper(self, *args, **kwargs):
-        if hasattr(self, '_done_'):
+        if hasattr(self, "_done_"):
             return f(self, *args, **kwargs)
         raise exc.NotFinalized(
-            "Ciphers must be finalized before calling this method.")
+            "Ciphers must be finalized before calling this method."
+        )
 
     return wrapper
 
@@ -258,8 +259,7 @@ def after_finalized(f):
 
 def cipher(cls):
     """Decorator to create a Cipher wrapper.
-    It must be applied on a class that derives from
-    `Cipher` class.
+    It must be applied on a class that derives from :any:`Cipher` class.
     """
     if not issubclass(cls, Cipher):
         raise TypeError(f"Class must be derived from `{Cipher.__name__}`")
