@@ -30,7 +30,7 @@ def generate(curve, *, backend=None):
     return _load_ecc_cpr(backend).ECCPrivateKey(curve)
 
 
-def load_public_key(data, *, backend=None):
+def load_public_key(data, *, edwards=None, backend=None):
     """Loads the public key and returns a Key interface.
 
     Args:
@@ -38,16 +38,25 @@ def load_public_key(data, *, backend=None):
             The public key (a bytes-like object) to deserialize.
 
     Keyword Arguments:
+        edwards (bool, NoneType):
+            Whether the `Raw` encoded key of length 32 bytes
+            must be imported as an `Ed25519` key or `X25519` key.
+
+            If `True`, the key will be imported as an `Ed25519` key,
+            otherwise an `X25519` key.
         backend (:class:`pyflocker.ciphers.backends.Backends`):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
         :any:`BasePublicKey`: An `ECCPublicKey` interface.
     """
-    return _load_ecc_cpr(backend).ECCPublicKey.load(data)
+    kwargs = dict()
+    if len(data) == 32:
+        kwargs = dict(edwards=edwards)
+    return _load_ecc_cpr(backend).ECCPublicKey.load(data, **kwargs)
 
 
-def load_private_key(data, passphrase=None, *, backend=None):
+def load_private_key(data, passphrase=None, *, edwards=None, backend=None):
     """Loads the private key and returns a Key interface.
 
     If the private key was not encrypted duting the serialization,
@@ -61,10 +70,23 @@ def load_private_key(data, passphrase=None, *, backend=None):
             private key. `None` if the key was not encrypted.
 
     Keyword Arguments:
+        edwards (bool, NoneType):
+            Whether the `Raw` encoded key of length 32 bytes
+            must be imported as an `Ed25519` key or `X25519` key.
+
+            If `True`, the key will be imported as an `Ed25519` key,
+            otherwise an `X25519` key.
         backend (:class:`pyflocker.ciphers.backends.Backends`):
             The backend to use. It must be a value from `Backends`.
 
     Returns:
         :any:`BasePrivateKey`: An ECCPrivateKey interface.
     """
-    return _load_ecc_cpr(backend).ECCPrivateKey.load(data, passphrase)
+    kwargs = dict()
+    if len(data) == 32:
+        kwargs = dict(edwards=edwards)
+    return _load_ecc_cpr(backend).ECCPrivateKey.load(
+        data,
+        passphrase,
+        **kwargs,
+    )
